# coding:utf-8

import glob

"""
获取当前路径下所有内容
判断每个内容的类型（文件夹还是文件）
若是文件夹则继续递归查找
"""

path =  # 因为下文捕获不可读文件格式太多，所以这里直接指定了 "test04" 路径


def search(search_path, content):  # 定义 search() 函数，传入 "path" 文件路径， "target" 要查找的目标文件
    glob_path = glob.glob(search_path)

    for file_path in glob_path:  # for 循环判断递归查到的内容是文件夹还是文件
        if glob.os.path.isdir(file_path):  # 若是文件夹，继续将该文件夹的路径传给 search() 函数继续递归查找
            _path = glob.os.path.join(file_path, '*')
            search(_path, content)
        else:  # 若是文件，则将该查询到的文件所在路径插入 final_result 空列表
            try:
                f = open(file_path, 'r')  # 利用 open() 函数读取文件，并通过 try...except... 捕获不可读的文件格式（.zip 格式）
                file_content = f.read()
                if content in file_content:
                    print(file_path)

            except:
                continue
            finally:
                f.close()


if __name__ == '__main__':
    result = search(r'D:\work\BaiduNetdiskWorkspace\personal' , content='runserver')
    # print(result)



from win32com.client import constants, gencache
import os  # 目录的操作


def createpdf(wordPath, pdfPath):
    word = gencache.EnsureDispatch('Word.Application')
    doc = word.Documents.Open(wordPath, ReadOnly=1)
    # 转换方法
    doc.ExportAsFixedFormat(pdfPath, constants.wdExportFormatPDF)
    word.Quit()


# 单个文件转换
# createpdf('C:/Users/Administrator/PycharmProjects/Project3/info.docx','C:/Users/Administrator/PycharmProjects/Project3/info.pdf')

# 多个文件的转换:
# 自己指定路径，
# 为了适配wps不能转换doc的问题，这里限定：只能转换docx
def docx2pdf(path):
    print(os.listdir(path))  # 当前文件夹下的所有文件
    wordfiles = []
    for file in os.listdir('.'):
        if file.endswith(('.doc', '.docx')):  # 通过后缀找出所有的workd文件
            wordfiles.append(file)
    print(wordfiles)

    for file in wordfiles:
        # 获取文件路径
        filepath = os.path.abspath(file)
        index = filepath.rindex('.')
        # 通过截取获取pdfpath
        pdfpath = filepath[:index] + '.pdf'
        print(pdfpath)
        createpdf(filepath, pdfpath)
